pub enum VisibilitySetting {
Hidden,
Hover,
Always,
}Expand description
Controls when the name of a node is displayed next to it.
Variants
Hidden
Never show node names.
Hover
Only show the name of the node closest to the mouse pointer.
Always
Always show node names, subject to MapSettings::label_visible_zoom.