Struct egui_map::map::SystemPoint
source · pub struct SystemPoint {
pub coords: [f64; 3],
pub lines: Vec<[f64; 3]>,
pub id: usize,
pub name: String,
/* private fields */
}Expand description
Struct that contains coordinates to help calculate nearest point in space
Fields
coords: [f64; 3]coordinates of the Solar System
lines: Vec<[f64; 3]>coordinates for lines connecting this point
id: usizeObject Identifier for search propurses
name: StringSolarSystem Name
Implementations
sourceimpl SystemPoint
impl SystemPoint
sourcepub fn new(id: usize, coords: Vec<f64>) -> SystemPoint
pub fn new(id: usize, coords: Vec<f64>) -> SystemPoint
Creates a new Spatial point with an Id (solarSystemId) and the system’s 3D coordinates
sourcepub fn get_dimension(self) -> usize
pub fn get_dimension(self) -> usize
Get the number of dimensions used in this object