Data types consumed by the Map widget.
This module contains the geometry primitives (RawPoint, RawLine),
the map content types (MapPoint, MapLine, MapLabel) and the
customization points of the widget: MapSettings, MapStyle,
VisibilitySetting, ContextMenuManager and NodeTemplate.
Structs
- MapLabel
- A free-floating text label drawn on the map.
- MapLine
- A connection line between two points on the map.
- MapPoint
- A node on the map: an id, a position and an optional display name.
- MapSettings
- Configuration of a
Mapwidget. - MapStyle
- Visual style used to paint the map under a given theme.
- RawLine
- A straight line segment between two
RawPoints. - RawPoint
- A point (or vector) in 2D map coordinates.
Enums
- Visibility
Setting - Controls when the name of a node is displayed next to it.
Traits
- Context
Menu Manager - Provides the contents of the widget’s right-click context menu.
- Node
Template - Customizes how nodes and their visual effects are rendered.