Struct egui_map::map::objects::MapPoint

source ·
pub struct MapPoint {
    pub coords: [f64; 3],
    pub lines: Vec<[f64; 3]>,
    pub id: usize,
    pub name: String,
    /* private fields */
}
Struct that contains coordinates to help calculate nearest point in space

Fields

coords: [f64; 3]

coordinates of the Solar System

lines: Vec<[f64; 3]>

coordinates for lines connecting this point

id: usize

Object Identifier for search propurses

name: String

SolarSystem Name

Implementations

source

impl MapPoint

source

pub fn new(id: usize, coords: Vec<f64>) -> MapPoint

Creates a new Spatial point with an Id (solarSystemId) and the system’s 3D coordinates

source

pub fn get_dimension(self) -> usize

Get the number of dimensions used in this object